==> gettext-0.15.tar.bz2: gettext-0.15/gettext-tools/woe32dll/gettextsrc-exports.c <==
/* List of exported symbols of libgettextsrc on Cygwin.
   Copyright (C) 2006 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2006.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */

#include "woe32dll/export.h"

VARIABLE(allow_duplicates)
VARIABLE(format_language)
VARIABLE(format_language_pretty)
VARIABLE(formatstring_awk)
VARIABLE(formatstring_boost)
VARIABLE(formatstring_c)
VARIABLE(formatstring_csharp)
VARIABLE(formatstring_elisp)
VARIABLE(formatstring_gcc_internal)
VARIABLE(formatstring_java)
VARIABLE(formatstring_librep)
VARIABLE(formatstring_lisp)
VARIABLE(formatstring_objc)
VARIABLE(formatstring_parsers)
VARIABLE(formatstring_pascal)
VARIABLE(formatstring_perl)
VARIABLE(formatstring_perl_brace)
VARIABLE(formatstring_php)
VARIABLE(formatstring_python)
VARIABLE(formatstring_qt)
VARIABLE(formatstring_scheme)
VARIABLE(formatstring_sh)
VARIABLE(formatstring_smalltalk)
VARIABLE(formatstring_tcl)
VARIABLE(formatstring_ycp)
VARIABLE(gram_max_allowed_errors)
VARIABLE(gram_pos)
VARIABLE(input_syntax)
VARIABLE(less_than)
VARIABLE(line_comment)
VARIABLE(more_than)
VARIABLE(msgcomm_mode)
VARIABLE(omit_header)
VARIABLE(pass_obsolete_entries)
VARIABLE(plural_table)
VARIABLE(plural_table_size)
VARIABLE(po_charset_ascii)
VARIABLE(po_charset_utf8)
VARIABLE(po_error)
VARIABLE(po_error_at_line)
VARIABLE(po_gram_lval)
VARIABLE(po_lex_charset)
VARIABLE(po_lex_iconv)
VARIABLE(po_lex_weird_cjk)
VARIABLE(po_multiline_error)
VARIABLE(po_multiline_warning)
VARIABLE(po_xerror)
VARIABLE(po_xerror2)
VARIABLE(use_first)

==> gettext-0.16.1.tar.bz2: gettext-0.16.1/gettext-tools/woe32dll/gettextsrc-exports.c <==
/* List of exported symbols of libgettextsrc on Cygwin.
   Copyright (C) 2006 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2006.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */

#include "woe32dll/export.h"

VARIABLE(allow_duplicates)
VARIABLE(format_language)
VARIABLE(format_language_pretty)
VARIABLE(formatstring_awk)
VARIABLE(formatstring_boost)
VARIABLE(formatstring_c)
VARIABLE(formatstring_csharp)
VARIABLE(formatstring_elisp)
VARIABLE(formatstring_gcc_internal)
VARIABLE(formatstring_java)
VARIABLE(formatstring_librep)
VARIABLE(formatstring_lisp)
VARIABLE(formatstring_objc)
VARIABLE(formatstring_parsers)
VARIABLE(formatstring_pascal)
VARIABLE(formatstring_perl)
VARIABLE(formatstring_perl_brace)
VARIABLE(formatstring_php)
VARIABLE(formatstring_python)
VARIABLE(formatstring_qt)
VARIABLE(formatstring_scheme)
VARIABLE(formatstring_sh)
VARIABLE(formatstring_smalltalk)
VARIABLE(formatstring_tcl)
VARIABLE(formatstring_ycp)
VARIABLE(gram_max_allowed_errors)
VARIABLE(gram_pos)
VARIABLE(input_format_po)
VARIABLE(input_format_properties)
VARIABLE(input_format_stringtable)
VARIABLE(less_than)
VARIABLE(line_comment)
VARIABLE(more_than)
VARIABLE(msgcomm_mode)
VARIABLE(omit_header)
VARIABLE(output_format_po)
VARIABLE(output_format_properties)
VARIABLE(output_format_stringtable)
VARIABLE(pass_obsolete_entries)
VARIABLE(plural_table)
VARIABLE(plural_table_size)
VARIABLE(po_charset_ascii)
VARIABLE(po_charset_utf8)
VARIABLE(po_error)
VARIABLE(po_error_at_line)
VARIABLE(po_gram_lval)
VARIABLE(po_lex_charset)
VARIABLE(po_lex_iconv)
VARIABLE(po_lex_weird_cjk)
VARIABLE(po_multiline_error)
VARIABLE(po_multiline_warning)
VARIABLE(po_xerror)
VARIABLE(po_xerror2)
VARIABLE(use_first)
